@@ -34,12 +34,12 @@ class Alarm : public QObject
 
 public:
     explicit Alarm();
-    explicit Alarm(QString uuid);
+    explicit Alarm(const QString &uuid);
 
     QUuid uuid() const;
 
     QString name() const;
-    void setName(QString name);
+    void setName(const QString &name);
 
     bool enabled() const;
     void setEnabled(bool enabled);
@@ -56,7 +56,7 @@ public:
     void setDaysOfWeek(int daysOfWeek);
 
     QString audioPath() const;
-    void setAudioPath(QString path);
+    void setAudioPath(const QString &path);
 
     int ringDuration() const;
     void setRingDuration(int ringDuration);
